imblearn.under_sampling.ClusterCentroids
========================================

.. currentmodule:: imblearn.under_sampling

.. autoclass:: ClusterCentroids

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ClusterCentroids.__init__
      ~ClusterCentroids.fit
      ~ClusterCentroids.fit_sample
      ~ClusterCentroids.get_params
      ~ClusterCentroids.sample
      ~ClusterCentroids.set_params
   
   

   
   
   